@@ -26,7 +26,7 @@ def on_message(client: mqtt.Client, userdata, msg):
         if command == 'train':
             add_task(msg_dict)
         elif command == 'ping':
-            reply_to_server({'success': True})
+            reply_to_server({'success': True, 'command': command})
         elif command == 'search':
             # Look for databases corresponding with tags
             databases = search_by_tags(msg_dict['tags'])
@@ -34,7 +34,7 @@ def on_message(client: mqtt.Client, userdata, msg):
                 # remove path from search to avoid privacy issues
                 for d in databases:
                     d.pop('path', None)
-                msg = {'success': True, 'databases': databases, 'count': len(databases)}
+                msg = {'success': True, 'command': command, 'databases': databases, 'count': len(databases)}
                 reply_to_server(msg)
 
         else:
@@ -42,7 +42,7 @@ def on_message(client: mqtt.Client, userdata, msg):
     except JSONDecodeError:
         reply_to_server({'success': False, 'msg': "Not able to deserialize the message"})
     except NotImplementedError:
-        reply_to_server({'success': False, 'msg': f"Command `{msg_dict['command']}` is not implemented"})
+        reply_to_server({'success': False, 'command': command, 'msg': f"Command `{command}` is not implemented"})
     except KeyError:
         reply_to_server({'success': False, 'msg': "'command' property was not found"})
     except TypeError:  # Message was not serializable
@@ -56,8 +56,11 @@ client.on_message = on_message
 client.connect(MQTT_BROKER, MQTT_BROKER_PORT, 60)
 
 
-def start_mqtt_service():
-    client.loop_start()
+def start_mqtt_service(block=False):
+    if block:
+        client.loop_forever()
+    else:
+        client.loop_start()
 
 
 from typing import Union
